.. _lino.coming:
.. _book.changes:
.. _lino.changes:

===============
Changes in Lino
===============

This covers changes in the the Lino framework, i.e. in :mod:`lino` (the "Core")
and :mod:`lino_xl` (the "Extensions Library").


.. toctree::
   :maxdepth: 1

   2019
   2018
   old

.. note:: Make sure to notify us if you run a production site using
   one of these applications.  We provide automatic database migration
   to future versions only for applications with at least one
   registered production site.

